==> haskell-vector-algorithms-0.9.1.0-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-algorithms
version:              0.9.1.0
visibility:           public
id:                   vector-algorithms-0.9.1.0-IhuvbuzuN9g8sa6z4ePqIs
key:                  vector-algorithms-0.9.1.0-IhuvbuzuN9g8sa6z4ePqIs
license:              BSD-3-Clause
copyright:
    (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
    (c) 2015 Tim Baumann

maintainer:
    Dan Doel <dan.doel@gmail.com>
    Erik de Castro Lopo <erikd@mega-nerd.com>

author:               Dan Doel
homepage:             https://github.com/erikd/vector-algorithms/
synopsis:             Efficient algorithms for vector arrays
description:
    Efficient algorithms for sorting vector arrays. At some stage
    other vector algorithms may be added.

category:             Data
abi:                  60d10d90cbf88bf2e2bc4376f2359ee2
exposed:              True
exposed-modules:
    Data.Vector.Algorithms Data.Vector.Algorithms.AmericanFlag
    Data.Vector.Algorithms.Heap Data.Vector.Algorithms.Insertion
    Data.Vector.Algorithms.Intro Data.Vector.Algorithms.Merge
    Data.Vector.Algorithms.Optimal Data.Vector.Algorithms.Radix
    Data.Vector.Algorithms.Search Data.Vector.Algorithms.Tim

hidden-modules:       Data.Vector.Algorithms.Common
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-algorithms-0.9.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-algorithms-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-algorithms-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-algorithms
hs-libraries:         HSvector-algorithms-0.9.1.0-IhuvbuzuN9g8sa6z4ePqIs
include-dirs:
    /usr/lib/ghc-9.4.8/site-local/vector-algorithms-0.9.1.0/include

depends:
    base-4.17.2.1 bitvec-1.1.5.0-2nf05OmdDluGNk2KPPp0LT
    bytestring-0.11.5.3 primitive-0.9.1.0-JdV7LeCcNMFKwvi67SGD5e
    vector-0.13.2.0-JPy5pohpq8EDknIfFhMz6E

haddock-interfaces:
    /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock

haddock-html:         /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-algorithms-0.9.1.0-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-algorithms
version:              0.9.1.0
visibility:           public
id:                   vector-algorithms-0.9.1.0-6m6EdhL5uMxARf6e1n1UBM
key:                  vector-algorithms-0.9.1.0-6m6EdhL5uMxARf6e1n1UBM
license:              BSD-3-Clause
copyright:
    (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
    (c) 2015 Tim Baumann

maintainer:
    Dan Doel <dan.doel@gmail.com>
    Erik de Castro Lopo <erikd@mega-nerd.com>

author:               Dan Doel
homepage:             https://github.com/erikd/vector-algorithms/
synopsis:             Efficient algorithms for vector arrays
description:
    Efficient algorithms for sorting vector arrays. At some stage
    other vector algorithms may be added.

category:             Data
abi:                  12ef567f4ad88257cbbe77d91f274fec
exposed:              True
exposed-modules:
    Data.Vector.Algorithms Data.Vector.Algorithms.AmericanFlag
    Data.Vector.Algorithms.Heap Data.Vector.Algorithms.Insertion
    Data.Vector.Algorithms.Intro Data.Vector.Algorithms.Merge
    Data.Vector.Algorithms.Optimal Data.Vector.Algorithms.Radix
    Data.Vector.Algorithms.Search Data.Vector.Algorithms.Tim

hidden-modules:       Data.Vector.Algorithms.Common
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-algorithms-0.9.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-algorithms-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-algorithms-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-algorithms
hs-libraries:         HSvector-algorithms-0.9.1.0-6m6EdhL5uMxARf6e1n1UBM
include-dirs:
    /usr/lib/ghc-9.4.8/site-local/vector-algorithms-0.9.1.0/include

depends:
    base-4.17.2.1 bitvec-1.1.5.0-C4540Y2Z0OgGsZvbWpv7Zl
    bytestring-0.11.5.3 primitive-0.9.1.0-HwFZTTOa0hJ3Qigb2ez2OX
    vector-0.13.2.0-HGgKaKiJszd4ty04a0OkB8

haddock-interfaces:
    /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock

haddock-html:         /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
